@@ -101,7 +101,8 @@ pip list
 echo Creating Virtual Environment
 virtualenv .task_venv --system-site-packages
 echo Activate Environment
-source .task_venv/bin/activate
+. .task_venv/bin/activate
+echo $PS1
 echo Run Main Command
 {command}
 export exit_code=$?
@@ -116,7 +117,7 @@ exit $exit_code"""
     def _install_command(self) -> str:
         repo_name = self.workflow_package.split(".")[0].replace("_", "-")
         version = self.workflow_version
-        return f"pip install {repo_name}=={version}"
+        return f"python -m pip install {repo_name}=={version}"
 
     @property
     def _run_command(self) -> str:
