@@ -10,6 +10,7 @@ from dkist_processing_core.build_utils import export
 from dkist_processing_core.build_utils import validate_workflows
 from dkist_processing_core.tests import invalid_workflow_package
 from dkist_processing_core.tests import valid_workflow_package
+from dkist_processing_core.tests import zero_node_workflow_package
 
 
 def test_validate_workflow_valid():
@@ -32,6 +33,17 @@ def test_validate_workflow_invalid():
         validate_workflows(invalid_workflow_package)
 
 
+def test_validate_workflow_zero_nodes():
+    """
+    Given: A workflow package with an invalid workflow of zero nodes
+    When: validating the workflow
+    Then: Errors raised
+    """
+    exceptions = (ValueError, AirflowException)
+    with pytest.raises(exceptions):
+        validate_workflows(zero_node_workflow_package)
+
+
 def test_export(export_path):
     """
     Given: A path to export to and a package containing a valid workflow
